]> git.donarmstrong.com Git - mothur.git/blobdiff - pintail.h
added pca command
[mothur.git] / pintail.h
index 289af65b68cb2f37ddf3c392cf9c67572dd5560b..516c682da3d9123cc07f9e6e143dd7fdc7d519c4 100644 (file)
--- a/pintail.h
+++ b/pintail.h
@@ -12,7 +12,9 @@
 
 #include "chimera.h"
 #include "dist.h"
+#include "decalc.h"
 
+/***********************************************************/
 //This class was created using the algorythms described in the 
 // "At Least 1 in 20 16S rRNA Sequence Records Currently Held in the Public Repositories is Estimated To Contain Substantial Anomalies" paper 
 //by Kevin E. Ashelford 1, Nadia A. Chuzhanova 3, John C. Fry 1, Antonia J. Jones 2 and Andrew J. Weightman 1.
@@ -25,7 +27,7 @@ class Pintail : public Chimera {
                Pintail(string, string);        
                ~Pintail();
                
-               void getChimeras();
+               int getChimeras();
                void print(ostream&);
                
                void setCons(string c)          { consfile = c;  }
@@ -34,29 +36,27 @@ class Pintail : public Chimera {
                
        private:
        
-               struct linePair {
-                       int start;
-                       int end;
-                       linePair(int i, int j) : start(i), end(j) {}
-               };
-
                Dist* distcalculator;
+               DeCalculator* decalc;
                int iters;
-               string fastafile, templateFile, consfile, quanfile;
+               string fastafile, templateFile, consfile;
+               
                
                vector<linePair*> lines;
+               vector<linePair*> templateLines;
                vector<Sequence*> querySeqs;
                vector<Sequence*> templateSeqs;
                
-               vector<Sequence> bestfit;  //bestfit[0] matches queryseqs[0]...
+               vector<Sequence*> bestfit;  //bestfit[0] matches queryseqs[0]...
                
                vector< vector<float> > obsDistance;  //obsDistance[0] is the vector of observed distances for queryseqs[0]... 
                vector< vector<float> > expectedDistance;  //expectedDistance[0] is the vector of expected distances for queryseqs[0]... 
                vector<float> deviation;  //deviation[0] is the percentage of mismatched pairs over the whole seq between querySeqs[0] and its best match.
-               vector< vector<int> > windows;  // windows[0] is a vector containing the starting spot in queryseqs[0] aligned sequence for each window.
+               vector< vector<int> > windowsForeachQuery;  // windowsForeachQuery[0] is a vector containing the starting spot in queryseqs[0] aligned sequence for each window.
                                                                                //this is needed so you can move by bases and not just spots in the alignment
                                                                                
-               vector<int> windowSizes;    //windowSizes[0] = window size of querySeqs[0]
+               vector<int> windowSizes;                        //windowSizes[0] = window size of querySeqs[0]
+               vector<int> windowSizesTemplate;    //windowSizesTemplate[0] = window size of templateSeqs[0]
                
                vector< map<int, int> > trimmed;    //trimmed[0] = start and stop of trimmed sequences for querySeqs[0]
                map<int, int>::iterator it;
@@ -66,30 +66,18 @@ class Pintail : public Chimera {
                vector<float> DE;                                       //DE[0] is the deviaation for queryseqs[0]...
                vector<float> probabilityProfile;
                vector< vector<float> > quantiles;  //quantiles[0] is the vector of deviations with ceiling score of 1, quantiles[1] is the vector of deviations with ceiling score of 2...
-               
-               vector<Sequence*> readSeqs(string);
-               map<int, int> trimSeqs(Sequence*, Sequence, int);
-               vector<float> readFreq();
-               vector< vector<float> > readQuantiles();
-               vector< vector<float> > getQuantiles(int, int);
-               vector<float> calcFreq(vector<Sequence*>);
+               vector< vector<quanMember> > quantilesMembers;  //quantiles[0] is the vector of deviations with ceiling score of 1, quantiles[1] is the vector of deviations with ceiling score of 2...
+               vector< set<int> > h;
                
                
-               vector<Sequence> findPairs(int, int);
-               vector<int> findWindows(Sequence*, int, int, int&);
-               vector<float> calcObserved(Sequence*, Sequence, vector<int>, int);
-               vector<float>  calcExpected(vector<float>, float);
-               vector<float>  findQav(vector<int>, int);  
-               float calcDE(vector<float>, vector<float>);
-               float calcDist(Sequence*, Sequence, int, int);
-               float getCoef(vector<float>, vector<float>);
-       
+               vector<float> readFreq();
+               vector<Sequence*> findPairs(int, int);
+                       
                void createProcessesSpots();
+               void createProcessesPairs();
                void createProcesses();
                void createProcessesQuan();
                
-               
-               
 };
 
 /***********************************************************/